Welcome to alpyen's documentation!
======================================
   
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

.. automodule:: alpyen.signal
   :members:
   :undoc-members:
.. automodule:: alpyen.strategy
   :members:
   :undoc-members:
.. automodule:: alpyen.backtesting
   :members:
   :undoc-members:
.. automodule:: alpyen.brokerinterface
   :members:
   :undoc-members:
.. automodule:: alpyen.livetrading
   :members:
   :undoc-members:

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
